Name:           yara
Version:        4.3.2
%global         baserelease 2.2
Summary:        Pattern matching Swiss knife for malware researchers
URL:            https://VirusTotal.github.io/yara/
VCS:            https://github.com/VirusTotal/yara/

License:        BSD-3-Clause

%global         common_description %{expand:
YARA is a tool aimed at (but not limited to) helping malware researchers to
identify and classify malware samples. With YARA you can create descriptions
of malware families (or whatever you want to describe) based on textual or
binary patterns. Each description, a.k.a rule, consists of a set of strings
and a Boolean expression which determine its logic.}


%global         gituser         VirusTotal
%global         gitname         yara
%global         gitdate         20230420
%global         commit          a6f6ce1d6d74a03c396660db25765f2a794d9e30
%global         shortcommit     %(c=%{commit}; echo ${c:0:7})

%bcond_without  release


%if %{with release}
Release:    1%{?dist}
Source0:       https://github.com/%{gituser}/%{gitname}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
%else
Release:    1%{?dist}
Source0:       https://github.com/%{gituser}/%{gitname}/archive/%{commit}/%{name}-%{version}-git%{gitdate}-%{shortcommit}.tar.gz
%endif

Patch1:         yara-docs-theme.patch


BuildRequires:  git
BuildRequires:  gcc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  m4
BuildRequires:  binutils
BuildRequires:  coreutils
BuildRequires:  sharutils
BuildRequires:  file
BuildRequires:  sed
BuildRequires:  gawk
BuildRequires:  gzip
BuildRequires:  xz
BuildRequires:  pcre
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libtool
BuildRequires:  file-devel
BuildRequires:  jansson-devel >= 2.5
BuildRequires:  protobuf-c-devel
BuildRequires:  protobuf-compiler

BuildRequires:  openssl-devel

BuildRequires:  /usr/bin/sphinx-build

%description
%{common_description}

%package doc
Summary:        Documentation for %{name}
BuildArch:      noarch

%description doc
This package contains documentation for %{name}.
%{common_description}


%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}


%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.
%{common_description}

%prep
%if %{with release}
    %autosetup -n %{gitname}-%{version} -p 1 -S git
%else
    %autosetup -n %{gitname}-%{commit} -p 1 -S git
%endif
autoreconf --force --install

%build


%configure --enable-magic --enable-cuckoo --enable-debug --enable-dotnet \
        --enable-macho --enable-dex --enable-pb-tests \
        --with-crypto \
        --htmldir=%{_datadir}/doc/%{name}/html
%make_build

pushd docs
make html
popd


%install
%make_install

rm %{buildroot}%{_libdir}/lib%{name}.la
rm %{buildroot}%{_libdir}/lib%{name}.a

rm -f %{buildroot}%{_datadir}/doc/%{name}/html/.buildinfo



%check
export OPENSSL_ENABLE_SHA1_SIGNATURES=yes
make check || (
    echo "===== ./test-suite.log"
    [ -f ./test-suite.log ] && cat ./test-suite.log
    echo "===== /proc/cpu"
    head -n 35 /proc/cpuinfo
    echo "===== /etc/os-release"
    cat /etc/os-release
    echo "===== uname -a"
    uname -a

%ifarch s390x
    true
%else
    false
%endif
)

%files
%license COPYING
%doc AUTHORS CONTRIBUTORS README.md
%{_bindir}/%{name}
%{_bindir}/%{name}c
%{_libdir}/lib%{name}.so.*
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/%{name}c.1*


%files devel
%{_includedir}/%{name}.h
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc


%files doc
%license COPYING
%doc docs/_build/html


%changelog
* Mon Jul 15 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.3.2-1
- initial build
